@@ -132,6 +132,7 @@
 
 .CacheSideEffectFn1 <- function(output, sideEffect, cacheRepo, quick, algo, FUN, ...) {
   message("sideEffect argument is poorly tested. It may not function as desired")
+  browser(expr = exists("sideE"))
   needDwd <- logical(0)
   fromCopy <- character(0)
   cachedChcksum <- attributes(output)$chcksumFiles
@@ -144,7 +145,7 @@
       if (file.exists(chcksumPath)) {
         checkDigest <- TRUE
       } else {
-        checkCopy <- file.path(cacheRepo, "gallery", basename(chcksumName))
+        checkCopy <- file.path(CacheStorageDir(cacheRepo), basename(chcksumName))
         if (file.exists(checkCopy)) {
           chcksumPath <- checkCopy
           checkDigest <- TRUE
@@ -189,7 +190,7 @@
   }
 
   if (NROW(fromCopy)) {
-    repoTo <- file.path(cacheRepo, "gallery")
+    repoTo <- CacheStorageDir(cacheRepo)
     lapply(fromCopy, function(x) {
       file.copy(from = file.path(repoTo, basename(x)),
                 to = file.path(cacheRepo), recursive = TRUE)
@@ -199,6 +200,7 @@
 
 .CacheSideEffectFn2 <- function(sideEffect, cacheRepo, priorRepo, algo, output,
                                 makeCopy, quick) {
+  browser(expr = exists("sideE"))
   if (isTRUE(sideEffect)) {
     postRepo <- list.files(cacheRepo, full.names = TRUE)
   } else {
@@ -225,8 +227,9 @@
     if (!identical(attr(output, "chcksumFiles"), paste0(cacheName, ":", cachecurFlst)))
       stop("There is an unknown error 01")
 
+    browser(expr = exists("sideE"))
     if (makeCopy) {
-      repoTo <- file.path(cacheRepo, "gallery")
+      repoTo <- CacheStorageDir(cacheRepo)
       checkPath(repoTo, create = TRUE)
       lapply(dwdFlst, function(x) {
         file.copy(from = x, to = file.path(repoTo), recursive = TRUE)
@@ -236,49 +239,37 @@
   return(output)
 }
 
-.addTagsRepo <- function(isInRepo, cacheRepo, lastOne) {
-  written <- 0
-  while (written >= 0) {
-    saved <- suppressWarnings(try(silent = TRUE,
-                                  addTagsRepo(isInRepo$artifact[lastOne],
-                                              repoDir = cacheRepo,
-                                              tags = paste0("accessed:", Sys.time()))))
-    written <- if (is(saved, "try-error")) {
-      Sys.sleep(sum(runif(written + 1,0.05, 0.1)))
-      written + 1
-    } else {
-      -1
-    }
-  }
-
-}
-
 .getFromRepo <- function(FUN, isInRepo, notOlderThan, lastOne, cacheRepo, fnDetails,
                          modifiedDots, debugCache, verbose, sideEffect, quick,
-                         algo, preDigest, startCacheTime, ...) {
-
+                         algo, preDigest, startCacheTime,
+                         drv = getOption("reproducible.drv", RSQLite::SQLite()),
+                         conn = getOption("reproducible.conn", NULL), ...) {
   if (verbose > 1) {
     startLoadTime <- Sys.time()
   }
 
+  cacheObj <- isInRepo[[.cacheTableHashColName()]][lastOne]
+
   fromMemoise <- NA
   if (getOption("reproducible.useMemoise")) {
     fromMemoise <-
-      if (memoise::has_cache(.loadFromLocalRepoMem)(isInRepo$artifact[lastOne],
-                                                    repoDir = cacheRepo, value = TRUE)) {
+      if (memoise::has_cache(.loadFromLocalRepoMem)(cacheObj, repoDir = cacheRepo, value = TRUE)) {
         TRUE
       } else {
         FALSE
       }
-    loadFromMgs <- "Loading from memoise version of repo"
-    output <- .loadFromLocalRepoMem(isInRepo$artifact[lastOne],
-                                    repoDir = cacheRepo, value = TRUE)
+    loadFromMgs <- "Loading from memoised version of repo"
+    browser(expr = exists("eeee"))
+    output <- .loadFromLocalRepoMem(md5hash = cacheObj, repoDir = cacheRepo, value = TRUE)
     output <- unmakeMemoisable(output)
     #if (is(output, "simList_")) output <- as(output, "simList")
   } else {
     loadFromMgs <- "Loading from repo"
-    output <- loadFromLocalRepo(isInRepo$artifact[lastOne],
-                                repoDir = cacheRepo, value = TRUE)
+    if (useDBI()) {
+      output <- loadFromCache(cacheRepo, isInRepo$cacheId[lastOne])
+    } else {
+      output <- archivist::loadFromLocalRepo(cacheObj, repoDir = cacheRepo, value = TRUE)
+    }
   }
 
   if (verbose > 1) {
@@ -297,12 +288,17 @@
   }
 
   # Class-specific message
+  browser(expr = exists("dddd"))
   .cacheMessage(output, fnDetails$functionName,
                 fromMemoise = fromMemoise)
 
   # This is protected from multiple-write to SQL collisions
-  .addTagsRepo(isInRepo, cacheRepo, lastOne)
+  # .addTagsRepo(isInRepo, cacheRepo, lastOne, drv, conn = conn)
+  .addTagsRepo(cacheId = isInRepo[[.cacheTableHashColName()]][lastOne],
+               cachePath = cacheRepo,
+               drv = drv, conn = conn)
 
+  browser(expr = exists("sideE"))
   if (sideEffect != FALSE) {
     #if(isTRUE(sideEffect)) {
     .CacheSideEffectFn1(output, sideEffect, cacheRepo, quick, algo, FUN, ...)
@@ -345,5 +341,4 @@
       output <- NULL
 
   return(output)
-
 }
