@@ -54,7 +54,6 @@ if (getRversion() >= "3.1.0") {
 #'
 #' @author Alex Chubaty
 #' @export
-#' @importFrom dplyr arrange desc filter group_by left_join mutate rename row_number select
 #' @rdname Checksums
 #'
 #' @examples
@@ -204,16 +203,8 @@ setMethod(
     if (write) {
       writeChecksumsTable(out1, checksumFile, dotsWriteTable)
       txt <- txtRead
-      txt1 <- data.table::copy(txt)
       txt <- txt[out, on = colnames(out)]
-      txt1 <- dplyr::right_join(txt1, out)
-      # wh <- match(txt$file, basename(filesToCheck))
-      # wh <- na.omit(wh)
-      # if (length(wh) > 0) {
-      #   txt[wh,"checksum"] <- checksums[[1]]
-      #   txt[wh,"filesize"] <- checksums[[2]]
-      # }
-      # txt <- txt[wh,]
+      #txt1Old <- dplyr::right_join(txt1Old, out)
     }
     txt1 <- data.table::copy(txt)
 
@@ -243,48 +234,48 @@ setMethod(
       "filesize.y" = filesize
     )]
 
-    results.df1 <- out1 %>%
-      dplyr::mutate(actualFile = file) %>%
-      {
-        if (write) {
-          dplyr::right_join(txt, ., by = "file")
-        } else {
-          dplyr::left_join(txt, ., by = "file")
-        }
-      } %>%
-      dplyr::rename(expectedFile = file) %>%
-      dplyr::group_by(expectedFile) %>%
-      {
-        if (quickCheck) {
-          mutate(., result = ifelse(filesize.x != filesize.y, "FAIL", "OK"))
-        } else {
-          mutate(., result = ifelse(checksum.x != checksum.y, "FAIL", "OK"))
-        }
-      } %>%
-      dplyr::arrange(desc(result)) %>%
-      {
-        #if (quickCheck) {
-        select(
-          .,
-          "result",
-          "expectedFile",
-          "actualFile",
-          "checksum.x",
-          "checksum.y",
-          "algorithm.x",
-          "algorithm.y",
-          "filesize.x",
-          "filesize.y"
-        )
-        #} else {
-        #  select(., "result", "expectedFile", "actualFile", "checksum.x", "checksum.y",
-        #         "algorithm.x", "algorithm.y", "filesize.x", "filesize.y")
-        #}
-      } %>%
-      dplyr::filter(row_number() == 1L)
+    # results.df1 <- out1 %>%
+    #   dplyr::mutate(actualFile = file) %>%
+    #   {
+    #     if (write) {
+    #       dplyr::right_join(txt, ., by = "file")
+    #     } else {
+    #       dplyr::left_join(txt, ., by = "file")
+    #     }
+    #   } %>%
+    #   dplyr::rename(expectedFile = file) %>%
+    #   dplyr::group_by(expectedFile) %>%
+    #   {
+    #     if (quickCheck) {
+    #       mutate(., result = ifelse(filesize.x != filesize.y, "FAIL", "OK"))
+    #     } else {
+    #       mutate(., result = ifelse(checksum.x != checksum.y, "FAIL", "OK"))
+    #     }
+    #   } %>%
+    #   dplyr::arrange(desc(result)) %>%
+    #   {
+    #     #if (quickCheck) {
+    #     select(
+    #       .,
+    #       "result",
+    #       "expectedFile",
+    #       "actualFile",
+    #       "checksum.x",
+    #       "checksum.y",
+    #       "algorithm.x",
+    #       "algorithm.y",
+    #       "filesize.x",
+    #       "filesize.y"
+    #     )
+    #     #} else {
+    #     #  select(., "result", "expectedFile", "actualFile", "checksum.x", "checksum.y",
+    #     #         "algorithm.x", "algorithm.y", "filesize.x", "filesize.y")
+    #     #}
+    #   } %>%
+    #   dplyr::filter(row_number() == 1L)
 
-    if (!isTRUE(all.equal(as.data.frame(results.df1), as.data.frame(results.df))))
-      browser()
+    # if (!isTRUE(all.equal(as.data.frame(results.df1), as.data.frame(results.df))))
+    #   browser()
 
     return(invisible(results.df))
     #}
