@@ -33,6 +33,7 @@ tempdir2 <- function(sub) {
 #' @author Eliot McIntire
 #' @export
 #' @importFrom data.table copy
+#' @inheritParams Cache
 #' @rdname Copy
 #' @seealso \code{\link{.robustDigest}}
 #'
@@ -116,14 +117,17 @@ setMethod("Copy",
           })
 
 #' @rdname Copy
+#' @inheritParams DBI::dbConnect
 setMethod("Copy",
           signature(object = "Raster"),
-          definition = function(object, filebackedDir, ...) {
+          definition = function(object, filebackedDir,
+                                drv = getOption("reproducible.drv", RSQLite::SQLite()),
+                                conn = getOption("reproducible.conn", NULL), ...) {
             if (missing(filebackedDir)) {
               filebackedDir <- tempdir2(rndstr(1, 8))
             }
             if (!is.null(filebackedDir))
-              object <- .prepareFileBackedRaster(object, repoDir = filebackedDir)
+              object <- .prepareFileBackedRaster(object, repoDir = filebackedDir, drv = drv, conn = conn)
             object
           })
 
