@@ -20,8 +20,18 @@
 #'   \code{cachePath} \tab \code{.reproducibleTempCacheDir}
 #'                    \tab Used in \code{\link{Cache}} and many others.
 #'                    The default path for repositories if not passed as an argument.\cr
+#'   \code{cacheSaveFormat} \tab "rds" \tab What save format to use; currently,
+#'                          "qs" or "rds" \cr
+#'   \code{conn} \tab \code{NULL} \tab Sets a specific connection to a database, e.g.,
+#'                       \code{dbConnect(drv = RSQLite::SQLite())} or
+#'                       \code{dbConnect(drv = RPostgres::Postgres()}. For remote
+#'                       database servers, setting one connection may be far faster than using
+#'                       \code{drv} which must make a new connection every time. \cr
 #'   \code{destinationPath} \tab \code{NULL} \tab Used in \code{\link{prepInputs}},
 #'                               \code{\link{preProcess}}. Can be set globally here. \cr
+#'   \code{drv} \tab \code{RSQLite::SQLite()} \tab Sets the default driver for the backend
+#'                       database system. Only tested with \code{RSQLite::SQLite()} and
+#'                       \code{RPostgres::Postgres()} \cr
 #'   \code{futurePlan} \tab \code{FALSE} \tab On Linux OSs, \code{Cache} and \code{cloudCache}
 #'                          have some functionality that uses the \code{future} package.
 #'                          Default is to not use these, as they are experimental. They may,
@@ -38,10 +48,11 @@
 #'                               in their \code{destinationPath}, but also minimize
 #'                               re-downloading the same (perhaps large) file over and over
 #'                               for each project. Because the files are hardlinks, there
-#'                               is no extra space taken up by the apparently duplicated files\cr
+#'                               is no extra space taken up by the apparently duplicated files.\cr
 #'   \code{inputPathsRecursive} \tab \code{FALSE} \tab Used in \code{\link{prepInputs}},
 #'                               \code{\link{preProcess}}. Should the \code{reproducible.inputPaths}
-#'                               be searched recursively for existence of a file\cr
+#'                               be searched recursively for existence of a file.\cr
+#'   \code{nThreads} \tab \code{1} \tab The number of threads to use for reading/writing cache files.\cr
 #'   \code{overwrite} \tab \code{FALSE} \tab Used in \code{\link{prepInputs}}, \code{\link{preProcess}},
 #'                         \code{\link{downloadFile}}, and \code{\link{postProcess}}.\cr
 #'   \code{quick} \tab \code{FALSE} \tab Used in \code{\link{Cache}}. This will cause
@@ -71,9 +82,11 @@
 #'                         deleting objects. This, therefore, is most useful if the user is
 #'                         using unique values for \code{userTags}\cr
 #'   \code{useCloud} \tab Passed to \code{Cache}. Default \code{FALSE}.\cr
+#'   \code{useDBI} \tab \code{TRUE} \tab As of reproducible 0.3, the backend is now \code{DBI}
+#'                      package instead of \code{archivist}\cr
 #'   \code{useGDAL} \tab Passed to \code{useGDAL} in \code{projectInputs.Raster}.
 #'                   Default \code{TRUE}.\cr
-#'   \code{useMemoise} \tab \code{TRUE} \tab Used in \code{\link{Cache}}. If \code{TRUE},
+#'   \code{useMemoise} \tab \code{FALSE} \tab Used in \code{\link{Cache}}. If \code{TRUE},
 #'                   recovery of cached elements from the cacheRepo will use
 #'                   \code{memoise::memoise}. This means that the 3rd time running a function
 #'                   will be much faster than the 1st (create cache entry) or 2nd (recover
@@ -111,22 +124,27 @@
 reproducibleOptions <- function() {
   list( # nolint
     reproducible.ask = TRUE,
-    reproducible.cloudChecksumsFilename = file.path(dirname(.reproducibleTempCacheDir),
-                                                    "checksums.rds"),
+    reproducible.cloudChecksumsFilename = normPath(file.path(dirname(.reproducibleTempCacheDir),
+                                                    "checksums.rds")),
     reproducible.cachePath = normPath(file.path(.reproducibleTempCacheDir)),
+    reproducible.cacheSaveFormat = "rds",
+    reproducible.conn = NULL,
     reproducible.destinationPath = NULL,
+    reproducible.drv = RSQLite::SQLite(),
     reproducible.futurePlan = FALSE, #future::plan("multiprocess"), #memoise
     reproducible.inputPaths = NULL,
     reproducible.inputPathsRecursive = FALSE,
     reproducible.length = Inf,
+    reproducible.nThreads = 1,
     reproducible.overwrite = FALSE,
     reproducible.quick = FALSE,
     reproducible.showSimilar = FALSE,
     reproducible.showSimilarDepth = 3,
     reproducible.useCache = TRUE, # override Cache function
     reproducible.useCloud = FALSE, #
+    reproducible.useDBI = TRUE,
     reproducible.useGDAL = TRUE, #
-    reproducible.useMemoise = TRUE, #memoise
+    reproducible.useMemoise = FALSE, #memoise
     reproducible.useNewDigestAlgorithm = TRUE,
     reproducible.useragent = "http://github.com/PredictiveEcology/reproducible",
     reproducible.verbose = FALSE
