@@ -555,7 +555,8 @@ preProcess <- function(targetFile = NULL, url = NULL, archive = NULL, alsoExtrac
 .guessAtFile <- function(url, archive, targetFile, destinationPath) {
   guessedFile <- if (!is.null(url)) {
     if (grepl("drive.google.com", url)) {
-      if (url.exists(url)) {
+      ie <- isTRUE(internetExists())
+      if (ie) {
         assessGoogle(url = url, archive = archive,
                      targetFile = targetFile,
                      destinationPath = destinationPath)
